@@ -1,17 +1,19 @@
 
 import numpy as np
-from pymodaq.daq_utils.gui_utils.custom_app import CustomApp
-from pymodaq.daq_utils.gui_utils.dock import DockArea, Dock
-from pymodaq.daq_utils.config import Config, get_set_preset_path
+
+from pymodaq.utils.logger import set_logger, get_module_name
+from pymodaq.utils.gui_utils.custom_app import CustomApp
+from pymodaq.utils.gui_utils.dock import DockArea, Dock
+from pymodaq.utils.config import Config, get_set_preset_path
 from qtpy import QtWidgets
 from qtpy.QtCore import Signal, QLocale
 
-from pymodaq.daq_utils import gui_utils as gutils
-from pymodaq.daq_utils import daq_utils as utils
+from pymodaq.utils import gui_utils as gutils
+from pymodaq.utils import daq_utils as utils
 
 
 config = Config()
-logger = utils.set_logger(utils.get_module_name(__file__))
+logger = set_logger(get_module_name(__file__))
 
 
 class NonLinearScanner(CustomApp):
